# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/topicData/topicDataRecord.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.topicData import timestamp_pb2 as ubii_dot_proto__v2_dot_types_dot_topicData_dot_timestamp__pb2
from ubii.proto_v2.types.dataStructure import lists_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2
from ubii.proto_v2.types.dataStructure import vector2_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2
from ubii.proto_v2.types.dataStructure import vector3_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2
from ubii.proto_v2.types.dataStructure import vector4_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector4__pb2
from ubii.proto_v2.types.dataStructure import quaternion_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2
from ubii.proto_v2.types.dataStructure import matrix3x2_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix3x2__pb2
from ubii.proto_v2.types.dataStructure import matrix4x4_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix4x4__pb2
from ubii.proto_v2.types.dataStructure import color_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_color__pb2
from ubii.proto_v2.types.dataStructure import touchEvent_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_touchEvent__pb2
from ubii.proto_v2.types.dataStructure import keyEvent_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_keyEvent__pb2
from ubii.proto_v2.types.dataStructure import mouseEvent_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_mouseEvent__pb2
from ubii.proto_v2.types.dataStructure import myoEvent_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_myoEvent__pb2
from ubii.proto_v2.types.dataStructure import pose2d_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2
from ubii.proto_v2.types.dataStructure import pose3d_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose3d__pb2
from ubii.proto_v2.types.dataStructure import object2d_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object2d__pb2
from ubii.proto_v2.types.dataStructure import object3d_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object3d__pb2
from ubii.proto_v2.types.dataStructure import image_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_image__pb2
from ubii.proto_v2.types.sessions import session_pb2 as ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/topicData/topicDataRecord.proto',
  package='ubii.proto_v2.types.topicData',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3ubii/proto_v2/types/topicData/topicDataRecord.proto\x12\x1dubii.proto_v2.types.topicData\x1a-ubii/proto_v2/types/topicData/timestamp.proto\x1a-ubii/proto_v2/types/dataStructure/lists.proto\x1a/ubii/proto_v2/types/dataStructure/vector2.proto\x1a/ubii/proto_v2/types/dataStructure/vector3.proto\x1a/ubii/proto_v2/types/dataStructure/vector4.proto\x1a\x32ubii/proto_v2/types/dataStructure/quaternion.proto\x1a\x31ubii/proto_v2/types/dataStructure/matrix3x2.proto\x1a\x31ubii/proto_v2/types/dataStructure/matrix4x4.proto\x1a-ubii/proto_v2/types/dataStructure/color.proto\x1a\x32ubii/proto_v2/types/dataStructure/touchEvent.proto\x1a\x30ubii/proto_v2/types/dataStructure/keyEvent.proto\x1a\x32ubii/proto_v2/types/dataStructure/mouseEvent.proto\x1a\x30ubii/proto_v2/types/dataStructure/myoEvent.proto\x1a.ubii/proto_v2/types/dataStructure/pose2d.proto\x1a.ubii/proto_v2/types/dataStructure/pose3d.proto\x1a\x30ubii/proto_v2/types/dataStructure/object2d.proto\x1a\x30ubii/proto_v2/types/dataStructure/object3d.proto\x1a-ubii/proto_v2/types/dataStructure/image.proto\x1a*ubii/proto_v2/types/sessions/session.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\"\xa6\x11\n\x0fTopicDataRecord\x12\r\n\x05topic\x18\x01 \x01(\t\x12;\n\ttimestamp\x18\x02 \x01(\x0b\x32(.ubii.proto_v2.types.topicData.Timestamp\x12\x10\n\x06\x64ouble\x18\x03 \x01(\x01H\x00\x12\x0e\n\x04\x62ool\x18\x04 \x01(\x08H\x00\x12\x10\n\x06string\x18\x05 \x01(\tH\x00\x12\x0f\n\x05int32\x18\x17 \x01(\x05H\x00\x12\x0f\n\x05\x66loat\x18\x18 \x01(\x02H\x00\x12=\n\x07vector2\x18\x06 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2H\x00\x12\x46\n\x0cvector2_list\x18# \x01(\x0b\x32..ubii.proto_v2.types.dataStructure.Vector2ListH\x00\x12=\n\x07vector3\x18\x07 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector3H\x00\x12\x46\n\x0cvector3_list\x18$ \x01(\x0b\x32..ubii.proto_v2.types.dataStructure.Vector3ListH\x00\x12=\n\x07vector4\x18\x08 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector4H\x00\x12\x46\n\x0cvector4_list\x18% \x01(\x0b\x32..ubii.proto_v2.types.dataStructure.Vector4ListH\x00\x12\x43\n\nquaternion\x18\t \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.QuaternionH\x00\x12H\n\x0fquaternion_list\x18& \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.QuaternionH\x00\x12\x41\n\tmatrix3x2\x18\n \x01(\x0b\x32,.ubii.proto_v2.types.dataStructure.Matrix3x2H\x00\x12\x41\n\tmatrix4x4\x18\x0b \x01(\x0b\x32,.ubii.proto_v2.types.dataStructure.Matrix4x4H\x00\x12\x39\n\x05\x63olor\x18\x0c \x01(\x0b\x32(.ubii.proto_v2.types.dataStructure.ColorH\x00\x12\x44\n\x0btouch_event\x18\r \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.TouchEventH\x00\x12M\n\x10touch_event_list\x18\" \x01(\x0b\x32\x31.ubii.proto_v2.types.dataStructure.TouchEventListH\x00\x12@\n\tkey_event\x18\x0e \x01(\x0b\x32+.ubii.proto_v2.types.dataStructure.KeyEventH\x00\x12\x44\n\x0bmouse_event\x18\x0f \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.MouseEventH\x00\x12@\n\tmyo_event\x18\x10 \x01(\x0b\x32+.ubii.proto_v2.types.dataStructure.MyoEventH\x00\x12;\n\x06pose2D\x18\x11 \x01(\x0b\x32).ubii.proto_v2.types.dataStructure.Pose2DH\x00\x12;\n\x06pose3D\x18\x12 \x01(\x0b\x32).ubii.proto_v2.types.dataStructure.Pose3DH\x00\x12?\n\x08object2D\x18\x13 \x01(\x0b\x32+.ubii.proto_v2.types.dataStructure.Object2DH\x00\x12?\n\x08object3D\x18\x14 \x01(\x0b\x32+.ubii.proto_v2.types.dataStructure.Object3DH\x00\x12H\n\robject2D_list\x18\x15 \x01(\x0b\x32/.ubii.proto_v2.types.dataStructure.Object2DListH\x00\x12H\n\robject3D_list\x18\x16 \x01(\x0b\x32/.ubii.proto_v2.types.dataStructure.Object3DListH\x00\x12\x42\n\nint32_list\x18\x19 \x01(\x0b\x32,.ubii.proto_v2.types.dataStructure.Int32ListH\x00\x12\x42\n\nfloat_list\x18\x1a \x01(\x0b\x32,.ubii.proto_v2.types.dataStructure.FloatListH\x00\x12\x44\n\x0b\x64ouble_list\x18\x1b \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.DoubleListH\x00\x12\x44\n\x0bstring_list\x18\x1c \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.StringListH\x00\x12@\n\tbool_list\x18\x1d \x01(\x0b\x32+.ubii.proto_v2.types.dataStructure.BoolListH\x00\x12=\n\x07image2D\x18\x1e \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Image2DH\x00\x12\x46\n\x0cimage2D_list\x18\x1f \x01(\x0b\x32..ubii.proto_v2.types.dataStructure.Image2DListH\x00\x12\x38\n\x07session\x18  \x01(\x0b\x32%.ubii.proto_v2.types.sessions.SessionH\x00\x42\x06\n\x04type\"W\n\x13TopicDataRecordList\x12@\n\x08\x65lements\x18\x01 \x03(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecordb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_topicData_dot_timestamp__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector4__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix3x2__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix4x4__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_color__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_touchEvent__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_keyEvent__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_mouseEvent__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_myoEvent__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose3d__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object2d__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object3d__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_image__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,])




_TOPICDATARECORD = _descriptor.Descriptor(
  name='TopicDataRecord',
  full_name='ubii.proto_v2.types.topicData.TopicDataRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.double', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.bool', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int32', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.int32', index=5,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.float', index=6,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector2', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector2', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector2_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector2_list', index=8,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector3', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector3', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector3_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector3_list', index=10,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector4', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector4', index=11,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector4_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.vector4_list', index=12,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quaternion', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.quaternion', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quaternion_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.quaternion_list', index=14,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix3x2', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.matrix3x2', index=15,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix4x4', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.matrix4x4', index=16,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.color', index=17,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='touch_event', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.touch_event', index=18,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='touch_event_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.touch_event_list', index=19,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_event', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.key_event', index=20,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mouse_event', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.mouse_event', index=21,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='myo_event', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.myo_event', index=22,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose2D', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.pose2D', index=23,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose3D', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.pose3D', index=24,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object2D', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.object2D', index=25,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object3D', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.object3D', index=26,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object2D_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.object2D_list', index=27,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object3D_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.object3D_list', index=28,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int32_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.int32_list', index=29,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.float_list', index=30,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.double_list', index=31,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.string_list', index=32,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.bool_list', index=33,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image2D', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.image2D', index=34,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image2D_list', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.image2D_list', index=35,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.session', index=36,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ubii.proto_v2.types.topicData.TopicDataRecord.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1075,
  serialized_end=3289,
)


_TOPICDATARECORDLIST = _descriptor.Descriptor(
  name='TopicDataRecordList',
  full_name='ubii.proto_v2.types.topicData.TopicDataRecordList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.topicData.TopicDataRecordList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3291,
  serialized_end=3378,
)

_TOPICDATARECORD.fields_by_name['timestamp'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_timestamp__pb2._TIMESTAMP
_TOPICDATARECORD.fields_by_name['vector2'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2
_TOPICDATARECORD.fields_by_name['vector2_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2LIST
_TOPICDATARECORD.fields_by_name['vector3'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3
_TOPICDATARECORD.fields_by_name['vector3_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3LIST
_TOPICDATARECORD.fields_by_name['vector4'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector4__pb2._VECTOR4
_TOPICDATARECORD.fields_by_name['vector4_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector4__pb2._VECTOR4LIST
_TOPICDATARECORD.fields_by_name['quaternion'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2._QUATERNION
_TOPICDATARECORD.fields_by_name['quaternion_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2._QUATERNION
_TOPICDATARECORD.fields_by_name['matrix3x2'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix3x2__pb2._MATRIX3X2
_TOPICDATARECORD.fields_by_name['matrix4x4'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_matrix4x4__pb2._MATRIX4X4
_TOPICDATARECORD.fields_by_name['color'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_color__pb2._COLOR
_TOPICDATARECORD.fields_by_name['touch_event'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_touchEvent__pb2._TOUCHEVENT
_TOPICDATARECORD.fields_by_name['touch_event_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_touchEvent__pb2._TOUCHEVENTLIST
_TOPICDATARECORD.fields_by_name['key_event'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_keyEvent__pb2._KEYEVENT
_TOPICDATARECORD.fields_by_name['mouse_event'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_mouseEvent__pb2._MOUSEEVENT
_TOPICDATARECORD.fields_by_name['myo_event'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_myoEvent__pb2._MYOEVENT
_TOPICDATARECORD.fields_by_name['pose2D'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2._POSE2D
_TOPICDATARECORD.fields_by_name['pose3D'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose3d__pb2._POSE3D
_TOPICDATARECORD.fields_by_name['object2D'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object2d__pb2._OBJECT2D
_TOPICDATARECORD.fields_by_name['object3D'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object3d__pb2._OBJECT3D
_TOPICDATARECORD.fields_by_name['object2D_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object2d__pb2._OBJECT2DLIST
_TOPICDATARECORD.fields_by_name['object3D_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_object3d__pb2._OBJECT3DLIST
_TOPICDATARECORD.fields_by_name['int32_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._INT32LIST
_TOPICDATARECORD.fields_by_name['float_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._FLOATLIST
_TOPICDATARECORD.fields_by_name['double_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._DOUBLELIST
_TOPICDATARECORD.fields_by_name['string_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._STRINGLIST
_TOPICDATARECORD.fields_by_name['bool_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_lists__pb2._BOOLLIST
_TOPICDATARECORD.fields_by_name['image2D'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_image__pb2._IMAGE2D
_TOPICDATARECORD.fields_by_name['image2D_list'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_image__pb2._IMAGE2DLIST
_TOPICDATARECORD.fields_by_name['session'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_session__pb2._SESSION
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['double'])
_TOPICDATARECORD.fields_by_name['double'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['bool'])
_TOPICDATARECORD.fields_by_name['bool'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['string'])
_TOPICDATARECORD.fields_by_name['string'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['int32'])
_TOPICDATARECORD.fields_by_name['int32'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['float'])
_TOPICDATARECORD.fields_by_name['float'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector2'])
_TOPICDATARECORD.fields_by_name['vector2'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector2_list'])
_TOPICDATARECORD.fields_by_name['vector2_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector3'])
_TOPICDATARECORD.fields_by_name['vector3'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector3_list'])
_TOPICDATARECORD.fields_by_name['vector3_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector4'])
_TOPICDATARECORD.fields_by_name['vector4'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['vector4_list'])
_TOPICDATARECORD.fields_by_name['vector4_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['quaternion'])
_TOPICDATARECORD.fields_by_name['quaternion'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['quaternion_list'])
_TOPICDATARECORD.fields_by_name['quaternion_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['matrix3x2'])
_TOPICDATARECORD.fields_by_name['matrix3x2'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['matrix4x4'])
_TOPICDATARECORD.fields_by_name['matrix4x4'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['color'])
_TOPICDATARECORD.fields_by_name['color'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['touch_event'])
_TOPICDATARECORD.fields_by_name['touch_event'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['touch_event_list'])
_TOPICDATARECORD.fields_by_name['touch_event_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['key_event'])
_TOPICDATARECORD.fields_by_name['key_event'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['mouse_event'])
_TOPICDATARECORD.fields_by_name['mouse_event'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['myo_event'])
_TOPICDATARECORD.fields_by_name['myo_event'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['pose2D'])
_TOPICDATARECORD.fields_by_name['pose2D'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['pose3D'])
_TOPICDATARECORD.fields_by_name['pose3D'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['object2D'])
_TOPICDATARECORD.fields_by_name['object2D'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['object3D'])
_TOPICDATARECORD.fields_by_name['object3D'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['object2D_list'])
_TOPICDATARECORD.fields_by_name['object2D_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['object3D_list'])
_TOPICDATARECORD.fields_by_name['object3D_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['int32_list'])
_TOPICDATARECORD.fields_by_name['int32_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['float_list'])
_TOPICDATARECORD.fields_by_name['float_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['double_list'])
_TOPICDATARECORD.fields_by_name['double_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['string_list'])
_TOPICDATARECORD.fields_by_name['string_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['bool_list'])
_TOPICDATARECORD.fields_by_name['bool_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['image2D'])
_TOPICDATARECORD.fields_by_name['image2D'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['image2D_list'])
_TOPICDATARECORD.fields_by_name['image2D_list'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORD.oneofs_by_name['type'].fields.append(
  _TOPICDATARECORD.fields_by_name['session'])
_TOPICDATARECORD.fields_by_name['session'].containing_oneof = _TOPICDATARECORD.oneofs_by_name['type']
_TOPICDATARECORDLIST.fields_by_name['elements'].message_type = _TOPICDATARECORD
DESCRIPTOR.message_types_by_name['TopicDataRecord'] = _TOPICDATARECORD
DESCRIPTOR.message_types_by_name['TopicDataRecordList'] = _TOPICDATARECORDLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicDataRecord = _reflection.GeneratedProtocolMessageType('TopicDataRecord', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDATARECORD,
  '__module__' : 'ubii.proto_v2.types.topicData.topicDataRecord_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.topicData.TopicDataRecord)
  })
_sym_db.RegisterMessage(TopicDataRecord)

TopicDataRecordList = _reflection.GeneratedProtocolMessageType('TopicDataRecordList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDATARECORDLIST,
  '__module__' : 'ubii.proto_v2.types.topicData.topicDataRecord_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.topicData.TopicDataRecordList)
  })
_sym_db.RegisterMessage(TopicDataRecordList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.devices.topicDemux_pb_plus import (
    TopicDemux,
)

from ubii.proto_v1.types.devices.topicMux_pb_plus import (
    TopicMux,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicInputMapping",
        "TopicInputMappingList",
        "TopicOutputMapping",
        "TopicOutputMappingList",
        "IOMapping",
        "IOMappingList",
    }
)


class TopicInputMapping(Message):
    input_name = Field(
        STRING,
        number=1,
    )
    topic = Field(
        STRING,
        number=2,
        oneof='topic_source',
    )
    topic_mux = Field(
        TopicMux,
        number=3,
        oneof='topic_source',
    )



class TopicInputMappingList(Message):
    elements = RepeatedField(
        TopicInputMapping,
        number=1,
    )



class TopicOutputMapping(Message):
    output_name = Field(
        STRING,
        number=1,
    )
    topic = Field(
        STRING,
        number=2,
        oneof='topic_destination',
    )
    topic_demux = Field(
        TopicDemux,
        number=3,
        oneof='topic_destination',
    )



class TopicOutputMappingList(Message):
    elements = RepeatedField(
        TopicOutputMapping,
        number=1,
    )



class IOMapping(Message):
    processing_module_id = Field(
        STRING,
        number=1,
    )
    input_mappings = RepeatedField(
        TopicInputMapping,
        number=2,
    )
    output_mappings = RepeatedField(
        TopicOutputMapping,
        number=3,
    )
    processing_module_name = Field(
        STRING,
        number=4,
    )



class IOMappingList(Message):
    elements = RepeatedField(
        IOMapping,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicDemux",
        "TopicDemuxList",
    }
)


class TopicDemux(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    data_type = Field(
        STRING,
        number=3,
    )
    output_topic_format = Field(
        STRING,
        number=4,
    )



class TopicDemuxList(Message):
    elements = RepeatedField(
        TopicDemux,
        number=1,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/lists.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/lists.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/dataStructure/lists.proto\x12!ubii.proto_v2.types.dataStructure\"\x1e\n\nStringList\x12\x10\n\x08\x65lements\x18\x01 \x03(\t\"\x1e\n\nDoubleList\x12\x10\n\x08\x65lements\x18\x01 \x03(\x01\"\x1d\n\tFloatList\x12\x10\n\x08\x65lements\x18\x01 \x03(\x02\"\x1c\n\x08\x42oolList\x12\x10\n\x08\x65lements\x18\x01 \x03(\x08\"\x1d\n\tInt32List\x12\x10\n\x08\x65lements\x18\x01 \x03(\x05\x62\x06proto3'
)




_STRINGLIST = _descriptor.Descriptor(
  name='StringList',
  full_name='ubii.proto_v2.types.dataStructure.StringList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.StringList.elements', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=114,
)


_DOUBLELIST = _descriptor.Descriptor(
  name='DoubleList',
  full_name='ubii.proto_v2.types.dataStructure.DoubleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.DoubleList.elements', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=146,
)


_FLOATLIST = _descriptor.Descriptor(
  name='FloatList',
  full_name='ubii.proto_v2.types.dataStructure.FloatList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.FloatList.elements', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=177,
)


_BOOLLIST = _descriptor.Descriptor(
  name='BoolList',
  full_name='ubii.proto_v2.types.dataStructure.BoolList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.BoolList.elements', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=207,
)


_INT32LIST = _descriptor.Descriptor(
  name='Int32List',
  full_name='ubii.proto_v2.types.dataStructure.Int32List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.Int32List.elements', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=238,
)

DESCRIPTOR.message_types_by_name['StringList'] = _STRINGLIST
DESCRIPTOR.message_types_by_name['DoubleList'] = _DOUBLELIST
DESCRIPTOR.message_types_by_name['FloatList'] = _FLOATLIST
DESCRIPTOR.message_types_by_name['BoolList'] = _BOOLLIST
DESCRIPTOR.message_types_by_name['Int32List'] = _INT32LIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.lists_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.StringList)
  })
_sym_db.RegisterMessage(StringList)

DoubleList = _reflection.GeneratedProtocolMessageType('DoubleList', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLELIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.lists_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.DoubleList)
  })
_sym_db.RegisterMessage(DoubleList)

FloatList = _reflection.GeneratedProtocolMessageType('FloatList', (_message.Message,), {
  'DESCRIPTOR' : _FLOATLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.lists_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.FloatList)
  })
_sym_db.RegisterMessage(FloatList)

BoolList = _reflection.GeneratedProtocolMessageType('BoolList', (_message.Message,), {
  'DESCRIPTOR' : _BOOLLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.lists_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.BoolList)
  })
_sym_db.RegisterMessage(BoolList)

Int32List = _reflection.GeneratedProtocolMessageType('Int32List', (_message.Message,), {
  'DESCRIPTOR' : _INT32LIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.lists_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Int32List)
  })
_sym_db.RegisterMessage(Int32List)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Matrix4x4",
    }
)


class Matrix4x4(Message):
    m00 = Field(
        DOUBLE,
        number=1,
    )
    m01 = Field(
        DOUBLE,
        number=2,
    )
    m02 = Field(
        DOUBLE,
        number=3,
    )
    m03 = Field(
        DOUBLE,
        number=4,
    )
    m10 = Field(
        DOUBLE,
        number=5,
    )
    m11 = Field(
        DOUBLE,
        number=6,
    )
    m12 = Field(
        DOUBLE,
        number=7,
    )
    m13 = Field(
        DOUBLE,
        number=8,
    )
    m20 = Field(
        DOUBLE,
        number=9,
    )
    m21 = Field(
        DOUBLE,
        number=10,
    )
    m22 = Field(
        DOUBLE,
        number=11,
    )
    m23 = Field(
        DOUBLE,
        number=12,
    )
    m30 = Field(
        DOUBLE,
        number=13,
    )
    m31 = Field(
        DOUBLE,
        number=14,
    )
    m32 = Field(
        DOUBLE,
        number=15,
    )
    m33 = Field(
        DOUBLE,
        number=16,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    Enum,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
)

from ubii.proto_v1.types.sessions.ioMappings_pb_plus import (
    IOMapping,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Session",
        "SessionList",
        "SessionStatus",
    }
)


class SessionStatus(Enum):
    CREATED = 0
    RUNNING = 1
    PAUSED = 2
    STOPPED = 3


class Session(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    processing_modules = RepeatedField(
        ProcessingModule,
        number=3,
    )
    io_mappings = RepeatedField(
        IOMapping,
        number=4,
    )
    tags = RepeatedField(
        STRING,
        number=5,
    )
    description = Field(
        STRING,
        number=6,
    )
    authors = RepeatedField(
        STRING,
        number=7,
    )
    status = Field(
        SessionStatus,
        number=8,
    )
    editable = Field(
        BOOL,
        number=9,
    )



class SessionList(Message):
    elements = RepeatedField(
        Session,
        number=1,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/devices/topicDemux.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/devices/topicDemux.proto',
  package='ubii.proto_v2.types.devices',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,ubii/proto_v2/types/devices/topicDemux.proto\x12\x1bubii.proto_v2.types.devices\"V\n\nTopicDemux\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdata_type\x18\x03 \x01(\t\x12\x1b\n\x13output_topic_format\x18\x04 \x01(\t\"K\n\x0eTopicDemuxList\x12\x39\n\x08\x65lements\x18\x01 \x03(\x0b\x32\'.ubii.proto_v2.types.devices.TopicDemuxb\x06proto3'
)




_TOPICDEMUX = _descriptor.Descriptor(
  name='TopicDemux',
  full_name='ubii.proto_v2.types.devices.TopicDemux',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.devices.TopicDemux.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.devices.TopicDemux.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='ubii.proto_v2.types.devices.TopicDemux.data_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_topic_format', full_name='ubii.proto_v2.types.devices.TopicDemux.output_topic_format', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=163,
)


_TOPICDEMUXLIST = _descriptor.Descriptor(
  name='TopicDemuxList',
  full_name='ubii.proto_v2.types.devices.TopicDemuxList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.devices.TopicDemuxList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=240,
)

_TOPICDEMUXLIST.fields_by_name['elements'].message_type = _TOPICDEMUX
DESCRIPTOR.message_types_by_name['TopicDemux'] = _TOPICDEMUX
DESCRIPTOR.message_types_by_name['TopicDemuxList'] = _TOPICDEMUXLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicDemux = _reflection.GeneratedProtocolMessageType('TopicDemux', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDEMUX,
  '__module__' : 'ubii.proto_v2.types.devices.topicDemux_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.TopicDemux)
  })
_sym_db.RegisterMessage(TopicDemux)

TopicDemuxList = _reflection.GeneratedProtocolMessageType('TopicDemuxList', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDEMUXLIST,
  '__module__' : 'ubii.proto_v2.types.devices.topicDemux_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.TopicDemuxList)
  })
_sym_db.RegisterMessage(TopicDemuxList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/processing/lockstepProcessing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.topicData import topicDataRecord_pb2 as ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/processing/lockstepProcessing.proto',
  package='ubii.proto_v2.types.processing',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7ubii/proto_v2/types/processing/lockstepProcessing.proto\x12\x1eubii.proto_v2.types.processing\x1a\x33ubii/proto_v2/types/topicData/topicDataRecord.proto\"\x92\x01\n\x19LockstepProcessingRequest\x12\x1d\n\x15processing_module_ids\x18\x01 \x03(\t\x12?\n\x07records\x18\x02 \x03(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecord\x12\x15\n\rdelta_time_ms\x18\x03 \x01(\x05\"y\n\x17LockstepProcessingReply\x12\x1d\n\x15processing_module_ids\x18\x01 \x03(\t\x12?\n\x07records\x18\x02 \x03(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecordb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2.DESCRIPTOR,])




_LOCKSTEPPROCESSINGREQUEST = _descriptor.Descriptor(
  name='LockstepProcessingRequest',
  full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_ids', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.processing_module_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta_time_ms', full_name='ubii.proto_v2.types.processing.LockstepProcessingRequest.delta_time_ms', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=291,
)


_LOCKSTEPPROCESSINGREPLY = _descriptor.Descriptor(
  name='LockstepProcessingReply',
  full_name='ubii.proto_v2.types.processing.LockstepProcessingReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_module_ids', full_name='ubii.proto_v2.types.processing.LockstepProcessingReply.processing_module_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='records', full_name='ubii.proto_v2.types.processing.LockstepProcessingReply.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=414,
)

_LOCKSTEPPROCESSINGREQUEST.fields_by_name['records'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
_LOCKSTEPPROCESSINGREPLY.fields_by_name['records'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
DESCRIPTOR.message_types_by_name['LockstepProcessingRequest'] = _LOCKSTEPPROCESSINGREQUEST
DESCRIPTOR.message_types_by_name['LockstepProcessingReply'] = _LOCKSTEPPROCESSINGREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LockstepProcessingRequest = _reflection.GeneratedProtocolMessageType('LockstepProcessingRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPPROCESSINGREQUEST,
  '__module__' : 'ubii.proto_v2.types.processing.lockstepProcessing_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.LockstepProcessingRequest)
  })
_sym_db.RegisterMessage(LockstepProcessingRequest)

LockstepProcessingReply = _reflection.GeneratedProtocolMessageType('LockstepProcessingReply', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPPROCESSINGREPLY,
  '__module__' : 'ubii.proto_v2.types.processing.lockstepProcessing_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.LockstepProcessingReply)
  })
_sym_db.RegisterMessage(LockstepProcessingReply)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.handGestureType_pb_plus import (
    HandGestureType,
)

from ubii.proto_v1.types.dataStructure.quaternion_pb_plus import (
    Quaternion,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
)

from ubii.proto_v1.types.dataStructure.vector8_pb_plus import (
    Vector8,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "MyoEvent",
    }
)


class MyoEvent(Message):
    emg = Field(
        Vector8,
        number=1,
    )
    orientation = Field(
        Quaternion,
        number=2,
    )
    gyroscope = Field(
        Vector3,
        number=3,
    )
    accelerometer = Field(
        Vector3,
        number=4,
    )
    gesture = Field(
        HandGestureType,
        number=5,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.services.serviceReply_pb_plus import (
    ServiceReply,
)

from ubii.proto_v1.types.services.serviceRequest_pb_plus import (
    ServiceRequest,
)

from ubii.proto_v1.types.services.service_pb_plus import (
    Service,
    ServiceList,
)


__all__ = (
    "Service",
    "ServiceList",
    "ServiceReply",
    "ServiceRequest",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
    RepeatedField,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Vector3",
        "Vector3List",
    }
)


class Vector3(Message):
    x = Field(
        DOUBLE,
        number=1,
    )
    y = Field(
        DOUBLE,
        number=2,
    )
    z = Field(
        DOUBLE,
        number=3,
    )



class Vector3List(Message):
    elements = RepeatedField(
        Vector3,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Constants",
    }
)


class Constants(Message):
    class DefaultTopics(Message):
        class Services(Message):
            SERVER_CONFIG = Field(
                STRING,
                number=1,
            )
            CLIENT_REGISTRATION = Field(
                STRING,
                number=2,
            )
            CLIENT_DEREGISTRATION = Field(
                STRING,
                number=3,
            )
            CLIENT_GET_LIST = Field(
                STRING,
                number=4,
            )
            DEVICE_REGISTRATION = Field(
                STRING,
                number=5,
            )
            DEVICE_DEREGISTRATION = Field(
                STRING,
                number=6,
            )
            DEVICE_GET = Field(
                STRING,
                number=7,
            )
            DEVICE_GET_LIST = Field(
                STRING,
                number=8,
            )
            PM_DATABASE_SAVE = Field(
                STRING,
                number=9,
            )
            PM_DATABASE_DELETE = Field(
                STRING,
                number=10,
            )
            PM_DATABASE_GET = Field(
                STRING,
                number=11,
            )
            PM_DATABASE_GET_LIST = Field(
                STRING,
                number=12,
            )
            PM_DATABASE_ONLINE_GET_LIST = Field(
                STRING,
                number=13,
            )
            PM_DATABASE_LOCAL_GET_LIST = Field(
                STRING,
                number=14,
            )
            PM_RUNTIME_ADD = Field(
                STRING,
                number=15,
            )
            PM_RUNTIME_REMOVE = Field(
                STRING,
                number=16,
            )
            PM_RUNTIME_GET = Field(
                STRING,
                number=17,
            )
            PM_RUNTIME_GET_LIST = Field(
                STRING,
                number=18,
            )
            SESSION_DATABASE_SAVE = Field(
                STRING,
                number=19,
            )
            SESSION_DATABASE_DELETE = Field(
                STRING,
                number=20,
            )
            SESSION_DATABASE_GET = Field(
                STRING,
                number=21,
            )
            SESSION_DATABASE_GET_LIST = Field(
                STRING,
                number=22,
            )
            SESSION_DATABASE_ONLINE_GET_LIST = Field(
                STRING,
                number=23,
            )
            SESSION_DATABASE_LOCAL_GET_LIST = Field(
                STRING,
                number=24,
            )
            SESSION_RUNTIME_ADD = Field(
                STRING,
                number=25,
            )
            SESSION_RUNTIME_REMOVE = Field(
                STRING,
                number=26,
            )
            SESSION_RUNTIME_GET = Field(
                STRING,
                number=27,
            )
            SESSION_RUNTIME_GET_LIST = Field(
                STRING,
                number=28,
            )
            SESSION_RUNTIME_START = Field(
                STRING,
                number=29,
            )
            SESSION_RUNTIME_STOP = Field(
                STRING,
                number=30,
            )
            SESSION_RUNTIME_UPDATE = Field(
                STRING,
                number=31,
            )
            TOPIC_DEMUX_DATABASE_SAVE = Field(
                STRING,
                number=32,
            )
            TOPIC_DEMUX_DATABASE_DELETE = Field(
                STRING,
                number=33,
            )
            TOPIC_DEMUX_DATABASE_GET = Field(
                STRING,
                number=34,
            )
            TOPIC_DEMUX_DATABASE_GET_LIST = Field(
                STRING,
                number=35,
            )
            TOPIC_DEMUX_RUNTIME_GET = Field(
                STRING,
                number=36,
            )
            TOPIC_DEMUX_RUNTIME_GET_LIST = Field(
                STRING,
                number=37,
            )
            TOPIC_MUX_DATABASE_SAVE = Field(
                STRING,
                number=38,
            )
            TOPIC_MUX_DATABASE_DELETE = Field(
                STRING,
                number=39,
            )
            TOPIC_MUX_DATABASE_GET = Field(
                STRING,
                number=40,
            )
            TOPIC_MUX_DATABASE_GET_LIST = Field(
                STRING,
                number=41,
            )
            TOPIC_MUX_RUNTIME_GET = Field(
                STRING,
                number=42,
            )
            TOPIC_MUX_RUNTIME_GET_LIST = Field(
                STRING,
                number=43,
            )
            SERVICE_LIST = Field(
                STRING,
                number=44,
            )
            TOPIC_LIST = Field(
                STRING,
                number=45,
            )
            TOPIC_SUBSCRIPTION = Field(
                STRING,
                number=46,
            )
            LATENCY_CLIENTS_LIST = Field(
                STRING,
                number=47,
            )
        


        class InfoTopics(Message):
            REGEX_ALL_INFOS = Field(
                STRING,
                number=1,
            )
            REGEX_PM_INFOS = Field(
                STRING,
                number=2,
            )
            NEW_PM = Field(
                STRING,
                number=3,
            )
            START_PM = Field(
                STRING,
                number=4,
            )
            DELETE_PM = Field(
                STRING,
                number=5,
            )
            CHANGE_PM = Field(
                STRING,
                number=6,
            )
            PROCESSED_PM = Field(
                STRING,
                number=7,
            )
            REGEX_SESSION_INFOS = Field(
                STRING,
                number=8,
            )
            NEW_SESSION = Field(
                STRING,
                number=9,
            )
            DELETE_SESSION = Field(
                STRING,
                number=10,
            )
            CHANGE_SESSION = Field(
                STRING,
                number=11,
            )
            START_SESSION = Field(
                STRING,
                number=12,
            )
            STOP_SESSION = Field(
                STRING,
                number=13,
            )
            RUNNING_SESSION = Field(
                STRING,
                number=14,
            )
        


        SERVICES = Field(
            Services,
            number=1,
        )
        INFO_TOPICS = Field(
            InfoTopics,
            number=2,
        )
    


    class MsgTypes(Message):
        ERROR = Field(
            STRING,
            number=1,
        )
        SUCCESS = Field(
            STRING,
            number=2,
        )
        SERVER = Field(
            STRING,
            number=3,
        )
        CLIENT = Field(
            STRING,
            number=4,
        )
        CLIENT_LIST = Field(
            STRING,
            number=5,
        )
        DEVICE = Field(
            STRING,
            number=6,
        )
        DEVICE_LIST = Field(
            STRING,
            number=7,
        )
        COMPONENT = Field(
            STRING,
            number=8,
        )
        COMPONENT_LIST = Field(
            STRING,
            number=9,
        )
        TOPIC_MUX = Field(
            STRING,
            number=10,
        )
        TOPIC_MUX_LIST = Field(
            STRING,
            number=11,
        )
        TOPIC_DEMUX = Field(
            STRING,
            number=12,
        )
        TOPIC_DEMUX_LIST = Field(
            STRING,
            number=13,
        )
        SERVICE = Field(
            STRING,
            number=14,
        )
        SERVICE_LIST = Field(
            STRING,
            number=15,
        )
        SERVICE_REQUEST = Field(
            STRING,
            number=16,
        )
        SERVICE_REPLY = Field(
            STRING,
            number=17,
        )
        SERVICE_REUEST_TOPIC_SUBSCRIPTION = Field(
            STRING,
            number=18,
        )
        SESSION = Field(
            STRING,
            number=19,
        )
        SESSION_LIST = Field(
            STRING,
            number=20,
        )
        SESSION_IO_MAPPING = Field(
            STRING,
            number=21,
        )
        PM = Field(
            STRING,
            number=22,
        )
        PM_LIST = Field(
            STRING,
            number=24,
        )
        PM_MODULE_IO = Field(
            STRING,
            number=25,
        )
        PM_PROCESSING_MODE = Field(
            STRING,
            number=26,
        )
        TOPIC_DATA = Field(
            STRING,
            number=27,
        )
        TOPIC_DATA_RECORD = Field(
            STRING,
            number=28,
        )
        TOPIC_DATA_RECORD_LIST = Field(
            STRING,
            number=29,
        )
        TOPIC_DATA_TIMESTAMP = Field(
            STRING,
            number=30,
        )
        DATASTRUCTURE_BOOL = Field(
            STRING,
            number=31,
        )
        DATASTRUCTURE_BOOL_LIST = Field(
            STRING,
            number=32,
        )
        DATASTRUCTURE_INT32 = Field(
            STRING,
            number=33,
        )
        DATASTRUCTURE_INT32_LIST = Field(
            STRING,
            number=34,
        )
        DATASTRUCTURE_STRING = Field(
            STRING,
            number=35,
        )
        DATASTRUCTURE_STRING_LIST = Field(
            STRING,
            number=36,
        )
        DATASTRUCTURE_FLOAT = Field(
            STRING,
            number=37,
        )
        DATASTRUCTURE_FLOAT_LIST = Field(
            STRING,
            number=38,
        )
        DATASTRUCTURE_DOUBLE = Field(
            STRING,
            number=39,
        )
        DATASTRUCTURE_DOUBLE_LIST = Field(
            STRING,
            number=40,
        )
        DATASTRUCTURE_COLOR = Field(
            STRING,
            number=41,
        )
        DATASTRUCTURE_IMAGE = Field(
            STRING,
            number=42,
        )
        DATASTRUCTURE_IMAGE_LIST = Field(
            STRING,
            number=43,
        )
        DATASTRUCTURE_KEY_EVENT = Field(
            STRING,
            number=44,
        )
        DATASTRUCTURE_MATRIX_3X2 = Field(
            STRING,
            number=45,
        )
        DATASTRUCTURE_MATRIX_4X4 = Field(
            STRING,
            number=46,
        )
        DATASTRUCTURE_MOUSE_EVENT = Field(
            STRING,
            number=47,
        )
        DATASTRUCTURE_OBJECT2D = Field(
            STRING,
            number=48,
        )
        DATASTRUCTURE_OBJECT2D_LIST = Field(
            STRING,
            number=49,
        )
        DATASTRUCTURE_OBJECT3D = Field(
            STRING,
            number=50,
        )
        DATASTRUCTURE_OBJECT3D_LIST = Field(
            STRING,
            number=51,
        )
        DATASTRUCTURE_POSE2D = Field(
            STRING,
            number=52,
        )
        DATASTRUCTURE_POSE3D = Field(
            STRING,
            number=53,
        )
        DATASTRUCTURE_QUATERNION = Field(
            STRING,
            number=54,
        )
        DATASTRUCTURE_TOUCH_EVENT = Field(
            STRING,
            number=55,
        )
        DATASTRUCTURE_VECTOR2 = Field(
            STRING,
            number=56,
        )
        DATASTRUCTURE_VECTOR3 = Field(
            STRING,
            number=57,
        )
        DATASTRUCTURE_VECTOR4 = Field(
            STRING,
            number=58,
        )
        DATASTRUCTURE_VECTOR8 = Field(
            STRING,
            number=59,
        )
    


    DEFAULT_TOPICS = Field(
        DefaultTopics,
        number=1,
    )
    MSG_TYPES = Field(
        MsgTypes,
        number=2,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.servers.constants_pb_plus import (
    Constants,
)

from ubii.proto_v1.types.servers.server_pb_plus import (
    Server,
)


__all__ = (
    "Constants",
    "Server",
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/myoEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import vector8_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector8__pb2
from ubii.proto_v2.types.dataStructure import vector3_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2
from ubii.proto_v2.types.dataStructure import quaternion_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2
from ubii.proto_v2.types.dataStructure import handGestureType_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_handGestureType__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/myoEvent.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0ubii/proto_v2/types/dataStructure/myoEvent.proto\x12!ubii.proto_v2.types.dataStructure\x1a/ubii/proto_v2/types/dataStructure/vector8.proto\x1a/ubii/proto_v2/types/dataStructure/vector3.proto\x1a\x32ubii/proto_v2/types/dataStructure/quaternion.proto\x1a\x37ubii/proto_v2/types/dataStructure/handGestureType.proto\"\xce\x02\n\x08MyoEvent\x12\x37\n\x03\x65mg\x18\x01 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector8\x12\x42\n\x0borientation\x18\x02 \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.Quaternion\x12=\n\tgyroscope\x18\x03 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector3\x12\x41\n\raccelerometer\x18\x04 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector3\x12\x43\n\x07gesture\x18\x05 \x01(\x0e\x32\x32.ubii.proto_v2.types.dataStructure.HandGestureTypeb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector8__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_handGestureType__pb2.DESCRIPTOR,])




_MYOEVENT = _descriptor.Descriptor(
  name='MyoEvent',
  full_name='ubii.proto_v2.types.dataStructure.MyoEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emg', full_name='ubii.proto_v2.types.dataStructure.MyoEvent.emg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='ubii.proto_v2.types.dataStructure.MyoEvent.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gyroscope', full_name='ubii.proto_v2.types.dataStructure.MyoEvent.gyroscope', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerometer', full_name='ubii.proto_v2.types.dataStructure.MyoEvent.accelerometer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gesture', full_name='ubii.proto_v2.types.dataStructure.MyoEvent.gesture', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=629,
)

_MYOEVENT.fields_by_name['emg'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector8__pb2._VECTOR8
_MYOEVENT.fields_by_name['orientation'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2._QUATERNION
_MYOEVENT.fields_by_name['gyroscope'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3
_MYOEVENT.fields_by_name['accelerometer'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3
_MYOEVENT.fields_by_name['gesture'].enum_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_handGestureType__pb2._HANDGESTURETYPE
DESCRIPTOR.message_types_by_name['MyoEvent'] = _MYOEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MyoEvent = _reflection.GeneratedProtocolMessageType('MyoEvent', (_message.Message,), {
  'DESCRIPTOR' : _MYOEVENT,
  '__module__' : 'ubii.proto_v2.types.dataStructure.myoEvent_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.MyoEvent)
  })
_sym_db.RegisterMessage(MyoEvent)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Server",
    }
)


class Server(Message):
    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    ip_ethernet = Field(
        STRING,
        number=3,
    )
    ip_wlan = Field(
        STRING,
        number=4,
    )
    port_service_zmq = Field(
        STRING,
        number=5,
    )
    port_service_rest = Field(
        STRING,
        number=6,
    )
    port_topic_data_zmq = Field(
        STRING,
        number=7,
    )
    port_topic_data_ws = Field(
        STRING,
        number=8,
    )
    constants_json = Field(
        STRING,
        number=9,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/clients/client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.devices import device_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/clients/client.proto',
  package='ubii.proto_v2.types.clients',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(ubii/proto_v2/types/clients/client.proto\x12\x1bubii.proto_v2.types.clients\x1a(ubii/proto_v2/types/devices/device.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\"\x96\x03\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x34\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32#.ubii.proto_v2.types.devices.Device\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\x12processing_modules\x18\x06 \x03(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModule\x12$\n\x1cis_dedicated_processing_node\x18\x07 \x01(\x08\x12\x0f\n\x07host_ip\x18\x08 \x01(\t\x12\x15\n\rmetadata_json\x18\t \x01(\t\x12\x38\n\x05state\x18\n \x01(\x0e\x32).ubii.proto_v2.types.clients.Client.State\x12\x0f\n\x07latency\x18\x0b \x01(\x02\"2\n\x05State\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0f\n\x0bUNAVAILABLE\x10\x02\"C\n\nClientList\x12\x35\n\x08\x65lements\x18\x01 \x03(\x0b\x32#.ubii.proto_v2.types.clients.Clientb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,])



_CLIENT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='ubii.proto_v2.types.clients.Client.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=527,
  serialized_end=577,
)
_sym_db.RegisterEnumDescriptor(_CLIENT_STATE)


_CLIENT = _descriptor.Descriptor(
  name='Client',
  full_name='ubii.proto_v2.types.clients.Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.clients.Client.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.clients.Client.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devices', full_name='ubii.proto_v2.types.clients.Client.devices', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.clients.Client.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.clients.Client.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_modules', full_name='ubii.proto_v2.types.clients.Client.processing_modules', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dedicated_processing_node', full_name='ubii.proto_v2.types.clients.Client.is_dedicated_processing_node', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_ip', full_name='ubii.proto_v2.types.clients.Client.host_ip', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_json', full_name='ubii.proto_v2.types.clients.Client.metadata_json', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='ubii.proto_v2.types.clients.Client.state', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='ubii.proto_v2.types.clients.Client.latency', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=577,
)


_CLIENTLIST = _descriptor.Descriptor(
  name='ClientList',
  full_name='ubii.proto_v2.types.clients.ClientList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.clients.ClientList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=646,
)

_CLIENT.fields_by_name['devices'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_device__pb2._DEVICE
_CLIENT.fields_by_name['processing_modules'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULE
_CLIENT.fields_by_name['state'].enum_type = _CLIENT_STATE
_CLIENT_STATE.containing_type = _CLIENT
_CLIENTLIST.fields_by_name['elements'].message_type = _CLIENT
DESCRIPTOR.message_types_by_name['Client'] = _CLIENT
DESCRIPTOR.message_types_by_name['ClientList'] = _CLIENTLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Client = _reflection.GeneratedProtocolMessageType('Client', (_message.Message,), {
  'DESCRIPTOR' : _CLIENT,
  '__module__' : 'ubii.proto_v2.types.clients.client_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.clients.Client)
  })
_sym_db.RegisterMessage(Client)

ClientList = _reflection.GeneratedProtocolMessageType('ClientList', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTLIST,
  '__module__' : 'ubii.proto_v2.types.clients.client_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.clients.ClientList)
  })
_sym_db.RegisterMessage(ClientList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.general.error_pb_plus import (
    Error,
    ErrorList,
)

from ubii.proto_v1.types.general.success_pb_plus import (
    Success,
    SuccessList,
)


__all__ = (
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "TopicSubscription",
    }
)


class TopicSubscription(Message):
    client_id = Field(
        STRING,
        number=1,
    )
    subscribe_topics = RepeatedField(
        STRING,
        number=2,
    )
    unsubscribe_topics = RepeatedField(
        STRING,
        number=3,
    )
    subscribe_topic_regexp = RepeatedField(
        STRING,
        number=4,
    )
    unsubscribe_topic_regexp = RepeatedField(
        STRING,
        number=5,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    INT32,
    INT64,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Timestamp",
    }
)


class Timestamp(Message):
    seconds = Field(
        INT64,
        number=1,
    )
    nanos = Field(
        INT32,
        number=2,
    )
    millis = Field(
        INT64,
        number=3,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/sessions/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.sessions import ioMappings_pb2 as ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2
from ubii.proto_v2.types.processing import processingModule_pb2 as ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/sessions/session.proto',
  package='ubii.proto_v2.types.sessions',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*ubii/proto_v2/types/sessions/session.proto\x12\x1cubii.proto_v2.types.sessions\x1a-ubii/proto_v2/types/sessions/ioMappings.proto\x1a\x35ubii/proto_v2/types/processing/processingModule.proto\"\xb2\x02\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x12processing_modules\x18\x03 \x03(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModule\x12<\n\x0bio_mappings\x18\x04 \x03(\x0b\x32\'.ubii.proto_v2.types.sessions.IOMapping\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0f\n\x07\x61uthors\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.ubii.proto_v2.types.sessions.SessionStatus\x12\x10\n\x08\x65\x64itable\x18\t \x01(\x08\"F\n\x0bSessionList\x12\x37\n\x08\x65lements\x18\x01 \x03(\x0b\x32%.ubii.proto_v2.types.sessions.Session*B\n\rSessionStatus\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x62\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2.DESCRIPTOR,])

_SESSIONSTATUS = _descriptor.EnumDescriptor(
  name='SessionStatus',
  full_name='ubii.proto_v2.types.sessions.SessionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=559,
  serialized_end=625,
)
_sym_db.RegisterEnumDescriptor(_SESSIONSTATUS)

SessionStatus = enum_type_wrapper.EnumTypeWrapper(_SESSIONSTATUS)
CREATED = 0
RUNNING = 1
PAUSED = 2
STOPPED = 3



_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='ubii.proto_v2.types.sessions.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.sessions.Session.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.sessions.Session.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_modules', full_name='ubii.proto_v2.types.sessions.Session.processing_modules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_mappings', full_name='ubii.proto_v2.types.sessions.Session.io_mappings', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.sessions.Session.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.sessions.Session.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authors', full_name='ubii.proto_v2.types.sessions.Session.authors', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='ubii.proto_v2.types.sessions.Session.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editable', full_name='ubii.proto_v2.types.sessions.Session.editable', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=485,
)


_SESSIONLIST = _descriptor.Descriptor(
  name='SessionList',
  full_name='ubii.proto_v2.types.sessions.SessionList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.sessions.SessionList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=557,
)

_SESSION.fields_by_name['processing_modules'].message_type = ubii_dot_proto__v2_dot_types_dot_processing_dot_processingModule__pb2._PROCESSINGMODULE
_SESSION.fields_by_name['io_mappings'].message_type = ubii_dot_proto__v2_dot_types_dot_sessions_dot_ioMappings__pb2._IOMAPPING
_SESSION.fields_by_name['status'].enum_type = _SESSIONSTATUS
_SESSIONLIST.fields_by_name['elements'].message_type = _SESSION
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['SessionList'] = _SESSIONLIST
DESCRIPTOR.enum_types_by_name['SessionStatus'] = _SESSIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'ubii.proto_v2.types.sessions.session_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.Session)
  })
_sym_db.RegisterMessage(Session)

SessionList = _reflection.GeneratedProtocolMessageType('SessionList', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONLIST,
  '__module__' : 'ubii.proto_v2.types.sessions.session_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.sessions.SessionList)
  })
_sym_db.RegisterMessage(SessionList)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/services/request/topicSubscription.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/services/request/topicSubscription.proto',
  package='ubii.proto_v2.types.services.request',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<ubii/proto_v2/types/services/request/topicSubscription.proto\x12$ubii.proto_v2.types.services.request\"\x9e\x01\n\x11TopicSubscription\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x18\n\x10subscribe_topics\x18\x02 \x03(\t\x12\x1a\n\x12unsubscribe_topics\x18\x03 \x03(\t\x12\x1e\n\x16subscribe_topic_regexp\x18\x04 \x03(\t\x12 \n\x18unsubscribe_topic_regexp\x18\x05 \x03(\tb\x06proto3'
)




_TOPICSUBSCRIPTION = _descriptor.Descriptor(
  name='TopicSubscription',
  full_name='ubii.proto_v2.types.services.request.TopicSubscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ubii.proto_v2.types.services.request.TopicSubscription.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_topics', full_name='ubii.proto_v2.types.services.request.TopicSubscription.subscribe_topics', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_topics', full_name='ubii.proto_v2.types.services.request.TopicSubscription.unsubscribe_topics', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribe_topic_regexp', full_name='ubii.proto_v2.types.services.request.TopicSubscription.subscribe_topic_regexp', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribe_topic_regexp', full_name='ubii.proto_v2.types.services.request.TopicSubscription.unsubscribe_topic_regexp', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=261,
)

DESCRIPTOR.message_types_by_name['TopicSubscription'] = _TOPICSUBSCRIPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicSubscription = _reflection.GeneratedProtocolMessageType('TopicSubscription', (_message.Message,), {
  'DESCRIPTOR' : _TOPICSUBSCRIPTION,
  '__module__' : 'ubii.proto_v2.types.services.request.topicSubscription_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.services.request.TopicSubscription)
  })
_sym_db.RegisterMessage(TopicSubscription)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    Enum,
    FLOAT,
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.devices.device_pb_plus import (
    Device,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ProcessingModule,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Client",
        "ClientList",
    }
)


class Client(Message):
    class State(Enum):
        ACTIVE = 0
        INACTIVE = 1
        UNAVAILABLE = 2


    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    devices = RepeatedField(
        Device,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )
    processing_modules = RepeatedField(
        ProcessingModule,
        number=6,
    )
    is_dedicated_processing_node = Field(
        BOOL,
        number=7,
    )
    host_ip = Field(
        STRING,
        number=8,
    )
    metadata_json = Field(
        STRING,
        number=9,
    )
    state = Field(
        State,
        number=10,
    )
    latency = Field(
        FLOAT,
        number=11,
    )



class ClientList(Message):
    elements = RepeatedField(
        Client,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.pose3d_pb_plus import (
    Pose3D,
)

from ubii.proto_v1.types.dataStructure.vector3_pb_plus import (
    Vector3,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Object3D",
        "Object3DList",
    }
)


class Object3D(Message):
    id = Field(
        STRING,
        number=1,
    )
    pose = Field(
        Pose3D,
        number=2,
    )
    size = Field(
        Vector3,
        number=3,
    )
    user_data_json = Field(
        STRING,
        number=4,
    )



class Object3DList(Message):
    elements = RepeatedField(
        Object3D,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    Enum,
    Field,
    INT32,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "ProcessingMode",
        "ModuleIO",
        "ProcessingModule",
        "ProcessingModuleList",
    }
)


class ProcessingMode(Message):
    class Frequency(Message):
        hertz = Field(
            INT32,
            number=1,
        )
    


    class Lockstep(Message):
        process_request_endpoint = Field(
            STRING,
            number=1,
        )
    


    class TriggerOnInput(Message):
        min_delay_ms = Field(
            INT32,
            number=1,
        )
        all_inputs_need_update = Field(
            BOOL,
            number=2,
        )
    


    frequency = Field(
        Frequency,
        number=1,
        oneof='mode',
    )
    lockstep = Field(
        Lockstep,
        number=2,
        oneof='mode',
    )
    trigger_on_input = Field(
        TriggerOnInput,
        number=3,
        oneof='mode',
    )



class ModuleIO(Message):
    internal_name = Field(
        STRING,
        number=1,
    )
    message_format = Field(
        STRING,
        number=2,
    )



class ProcessingModule(Message):
    class Status(Enum):
        INITIALIZED = 0
        CREATED = 1
        PROCESSING = 2
        HALTED = 3
        DESTROYED = 4


    class Language(Enum):
        CPP = 0
        PY = 1
        JS = 2
        CS = 3
        JAVA = 4


    id = Field(
        STRING,
        number=1,
    )
    name = Field(
        STRING,
        number=2,
    )
    authors = RepeatedField(
        STRING,
        number=3,
    )
    tags = RepeatedField(
        STRING,
        number=4,
    )
    description = Field(
        STRING,
        number=5,
    )
    node_id = Field(
        STRING,
        number=6,
    )
    session_id = Field(
        STRING,
        number=7,
    )
    status = Field(
        Status,
        number=8,
    )
    processing_mode = Field(
        ProcessingMode,
        number=9,
    )
    inputs = RepeatedField(
        ModuleIO,
        number=10,
    )
    outputs = RepeatedField(
        ModuleIO,
        number=11,
    )
    language = Field(
        Language,
        number=12,
    )
    on_processing_stringified = Field(
        STRING,
        number=13,
    )
    on_created_stringified = Field(
        STRING,
        number=14,
    )
    on_halted_stringified = Field(
        STRING,
        number=15,
    )
    on_destroyed_stringified = Field(
        STRING,
        number=16,
    )



class ProcessingModuleList(Message):
    elements = RepeatedField(
        ProcessingModule,
        number=1,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/pose3d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import vector3_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2
from ubii.proto_v2.types.dataStructure import quaternion_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/pose3d.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.ubii/proto_v2/types/dataStructure/pose3d.proto\x12!ubii.proto_v2.types.dataStructure\x1a/ubii/proto_v2/types/dataStructure/vector3.proto\x1a\x32ubii/proto_v2/types/dataStructure/quaternion.proto\"\xd7\x01\n\x06Pose3D\x12<\n\x08position\x18\x01 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector3\x12\x43\n\nquaternion\x18\x02 \x01(\x0b\x32-.ubii.proto_v2.types.dataStructure.QuaternionH\x00\x12;\n\x05\x65uler\x18\x03 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector3H\x00\x42\r\n\x0borientationb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2.DESCRIPTOR,])




_POSE3D = _descriptor.Descriptor(
  name='Pose3D',
  full_name='ubii.proto_v2.types.dataStructure.Pose3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='ubii.proto_v2.types.dataStructure.Pose3D.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quaternion', full_name='ubii.proto_v2.types.dataStructure.Pose3D.quaternion', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='euler', full_name='ubii.proto_v2.types.dataStructure.Pose3D.euler', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='orientation', full_name='ubii.proto_v2.types.dataStructure.Pose3D.orientation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=187,
  serialized_end=402,
)

_POSE3D.fields_by_name['position'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3
_POSE3D.fields_by_name['quaternion'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_quaternion__pb2._QUATERNION
_POSE3D.fields_by_name['euler'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector3__pb2._VECTOR3
_POSE3D.oneofs_by_name['orientation'].fields.append(
  _POSE3D.fields_by_name['quaternion'])
_POSE3D.fields_by_name['quaternion'].containing_oneof = _POSE3D.oneofs_by_name['orientation']
_POSE3D.oneofs_by_name['orientation'].fields.append(
  _POSE3D.fields_by_name['euler'])
_POSE3D.fields_by_name['euler'].containing_oneof = _POSE3D.oneofs_by_name['orientation']
DESCRIPTOR.message_types_by_name['Pose3D'] = _POSE3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pose3D = _reflection.GeneratedProtocolMessageType('Pose3D', (_message.Message,), {
  'DESCRIPTOR' : _POSE3D,
  '__module__' : 'ubii.proto_v2.types.dataStructure.pose3d_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Pose3D)
  })
_sym_db.RegisterMessage(Pose3D)


# @@protoc_insertion_point(module_scope)



from .buttonEventType_pb2 import *
from .color_pb2 import *
from .handGestureType_pb2 import *
from .image_pb2 import *
from .keyEvent_pb2 import *
from .lists_pb2 import *
from .matrix3x2_pb2 import *
from .matrix4x4_pb2 import *
from .mouseEvent_pb2 import *
from .myoEvent_pb2 import *
from .object2d_pb2 import *
from .object3d_pb2 import *
from .pose2d_pb2 import *
from .pose3d_pb2 import *
from .quaternion_pb2 import *
from .touchEvent_pb2 import *
from .vector2_pb2 import *
from .vector3_pb2 import *
from .vector4_pb2 import *
from .vector8_pb2 import *


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/topicData/topicData.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.topicData import topicDataRecord_pb2 as ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2
from ubii.proto_v2.types.general import error_pb2 as ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/topicData/topicData.proto',
  package='ubii.proto_v2.types.topicData',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/topicData/topicData.proto\x12\x1dubii.proto_v2.types.topicData\x1a\x33ubii/proto_v2/types/topicData/topicDataRecord.proto\x1a\'ubii/proto_v2/types/general/error.proto\"\xeb\x01\n\tTopicData\x12K\n\x11topic_data_record\x18\x02 \x01(\x0b\x32..ubii.proto_v2.types.topicData.TopicDataRecordH\x00\x12T\n\x16topic_data_record_list\x18\x03 \x01(\x0b\x32\x32.ubii.proto_v2.types.topicData.TopicDataRecordListH\x00\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\".ubii.proto_v2.types.general.ErrorH\x00\x42\x06\n\x04typeb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2.DESCRIPTOR,])




_TOPICDATA = _descriptor.Descriptor(
  name='TopicData',
  full_name='ubii.proto_v2.types.topicData.TopicData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_data_record', full_name='ubii.proto_v2.types.topicData.TopicData.topic_data_record', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_data_record_list', full_name='ubii.proto_v2.types.topicData.TopicData.topic_data_record_list', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ubii.proto_v2.types.topicData.TopicData.error', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='ubii.proto_v2.types.topicData.TopicData.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=175,
  serialized_end=410,
)

_TOPICDATA.fields_by_name['topic_data_record'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORD
_TOPICDATA.fields_by_name['topic_data_record_list'].message_type = ubii_dot_proto__v2_dot_types_dot_topicData_dot_topicDataRecord__pb2._TOPICDATARECORDLIST
_TOPICDATA.fields_by_name['error'].message_type = ubii_dot_proto__v2_dot_types_dot_general_dot_error__pb2._ERROR
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['topic_data_record'])
_TOPICDATA.fields_by_name['topic_data_record'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['topic_data_record_list'])
_TOPICDATA.fields_by_name['topic_data_record_list'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
_TOPICDATA.oneofs_by_name['type'].fields.append(
  _TOPICDATA.fields_by_name['error'])
_TOPICDATA.fields_by_name['error'].containing_oneof = _TOPICDATA.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['TopicData'] = _TOPICDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicData = _reflection.GeneratedProtocolMessageType('TopicData', (_message.Message,), {
  'DESCRIPTOR' : _TOPICDATA,
  '__module__' : 'ubii.proto_v2.types.topicData.topicData_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.topicData.TopicData)
  })
_sym_db.RegisterMessage(TopicData)


# @@protoc_insertion_point(module_scope)
